WMR9x8 - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# WMR9x8

The station includes a data logger, but the driver does not read records from the station.

The station emits partial packets, which may confuse some online services.

## Configuring with `wee_device`

The WMR9x8 stations cannot be configured with the utility `wee_device`.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

WMR9x8 station data
Database Field | Observation | Loop | Archive
barometer | barometer | H |
pressure | pressure | H |
altimeter |  | S |
inTemp | temperature_in | H |
outTemp | temperature_out | H |
inHumidity | humidity_in | H |
outHumidity | humidity_out | H |
windSpeed | wind_speed | H |
windDir | wind_dir | H |
windGust | wind_gust | H |
windGustDir | wind_gust_dir | H |
rain | rain | D |
| rain_total | H |
rainRate | rain_rate | H |
inDewpoint | dewpoint_in | H |
dewpoint | dewpoint_out | H |
windchill | windchill | H |
heatindex |  | S |
UV | uv | H |
extraTemp1 | temperature_1 | H |
extraTemp2 | temperature_2 | H |
extraTemp3 | temperature_3 | H |
extraTemp4 | temperature_4 | H |
extraTemp5 | temperature_5 | H |
extraTemp6 | temperature_6 | H |
extraTemp7 | temperature_7 | H |
extraTemp8 | temperature_8 | H |
extraHumid1 | humidity_1 | H |
extraHumid2 | humidity_3 | H |
extraHumid3 | humidity_3 | H |
extraHumid4 | humidity_4 | H |
extraHumid5 | humidity_5 | H |
extraHumid6 | humidity_6 | H |
extraHumid7 | humidity_7 | H |
extraHumid8 | humidity_8 | H |
inTempBatteryStatus | battery_status_in | H |
outTempBatteryStatus | battery_status_out | H |
rainBatteryStatus | rain_battery_status | H |
windBatteryStatus | wind_battery_status | H |
extraBatteryStatus1 | battery_status_1 | H |
extraBatteryStatus2 | battery_status_2 | H |
extraBatteryStatus3 | battery_status_3 | H |
extraBatteryStatus4 | battery_status_4 | H |
extraBatteryStatus5 | battery_status_5 | H |
extraBatteryStatus6 | battery_status_6 | H |
extraBatteryStatus7 | battery_status_7 | H |
extraBatteryStatus8 | battery_status_8 | H |

Each packet contains a subset of all possible readings. For example, a temperature packet contains temperature_N and battery_status_N, a rain packet contains rain_total and rain_rate.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service